@@ -310,8 +310,8 @@ class Device(object):
                     "little",
                     False
                 )
-            elif bool(dict_io[key][7]) or isinstance(self, Base):
-                # Bei Bitwerten oder Base IOBase verwenden
+            elif bool(dict_io[key][7]):
+                # Bei Bitwerten IOBase verwenden
                 io_new = IOBase(
                     self, dict_io[key], iotype, "little", False
                 )
@@ -542,12 +542,13 @@ class Core(Base):
 
     __slots__ = "_slc_cycle", "_slc_errorcnt", "_slc_statusbyte", \
                 "_slc_temperature", "_slc_errorlimit1", "_slc_errorlimit2", \
-                "_slc_frequency", "_slc_led", "a1green", "a1red", "a2green", "a2red"
+                "_slc_frequency", "_slc_led", "a1green", "a1red", \
+                "a2green", "a2red", "wd"
 
     def __setattr__(self, key, value):
         """Verhindert Ueberschreibung der LEDs."""
         if hasattr(self, key) and key in (
-                "a1green", "a1red", "a2green", "a2red"):
+                "a1green", "a1red", "a2green", "a2red", "wd"):
             raise AttributeError(
                 "direct assignment is not supported - use .value Attribute"
             )
@@ -616,6 +617,12 @@ class Core(Base):
             exp_a2red, None, "LED_A2_RED", "3"
         ], OUT, "little", False)
 
+        # Watchdog einrichten (Core=soft / Connect=soft/hard)
+        self.wd = IOBase(self, [
+            "core.wd", 0, 1, self._slc_led.start,
+            False, None, "WatchDog", "7"
+        ], OUT, "little", False)
+
     def __errorlimit(self, slc_io: slice, errorlimit: int) -> None:
         """
         Verwaltet das Schreiben der ErrorLimits.
@@ -647,12 +654,8 @@ class Core(Base):
 
         :return: 0=aus, 1=gruen, 2=rot
         """
-        int_led = int.from_bytes(
-            self._ba_devdata[self._slc_led], byteorder="little"
-        )
-        led = int_led & 1
-        led += int_led & 2
-        return led
+        # 0b00000011 = 3
+        return self._ba_devdata[self._slc_led.start] & 3
 
     def _get_leda2(self) -> int:
         """
@@ -660,37 +663,8 @@ class Core(Base):
 
         :return: 0=aus, 1=gruen, 2=rot
         """
-        int_led = int.from_bytes(
-            self._ba_devdata[self._slc_led], byteorder="little"
-        ) >> 2
-        led = int_led & 1
-        led += int_led & 2
-        return led
-
-    def _set_calculatedled(self, addresslist: list, shifted_value: int) -> None:
-        """
-        Berechnet und setzt neuen Bytewert fuer LED byte.
-
-        :param addresslist: Liste der Vergleicher
-        :param shifted_value: Bits vergleichen
-        """
-        # Byte als int holen
-        int_led = int.from_bytes(
-            self._ba_devdata[self._slc_led], byteorder="little"
-        )
-
-        for int_bit in addresslist:
-            value = bool(shifted_value & int_bit)
-            if bool(int_led & int_bit) != value:
-                # Berechnen, wenn verändert
-                if value:
-                    int_led += int_bit
-                else:
-                    int_led -= int_bit
-
-        # Zurückschreiben wenn verändert
-        self._ba_devdata[self._slc_led] = \
-            int_led.to_bytes(length=1, byteorder="little")
+        # 0b00001100 = 12
+        return (self._ba_devdata[self._slc_led.start] & 12) >> 2
 
     def _set_leda1(self, value: int) -> None:
         """
@@ -699,7 +673,13 @@ class Core(Base):
         :param value: 0=aus, 1=gruen, 2=rot
         """
         if 0 <= value <= 3:
-            self._set_calculatedled([1, 2], value)
+            proc_value = self._ba_devdata[self._slc_led.start]
+            proc_value_calc = proc_value & 3
+            if proc_value_calc == value:
+                return
+            # Set new value
+            self._ba_devdata[self._slc_led.start] = \
+                proc_value - proc_value_calc + value
         else:
             raise ValueError("led status must be between 0 and 3")
 
@@ -710,10 +690,21 @@ class Core(Base):
         :param value: 0=aus, 1=gruen, 2=rot
         """
         if 0 <= value <= 3:
-            self._set_calculatedled([4, 8], value << 2)
+            value <<= 2
+            proc_value = self._ba_devdata[self._slc_led.start]
+            proc_value_calc = proc_value & 12
+            if proc_value_calc == value:
+                return
+            # Set new value
+            self._ba_devdata[self._slc_led.start] = \
+                proc_value - proc_value_calc + value
         else:
             raise ValueError("led status must be between 0 and 3")
 
+    def wd_toggle(self):
+        """Toggle watchdog bit to prevent a timeout."""
+        self.wd.value = not self.wd.value
+
     A1 = property(_get_leda1, _set_leda1)
     A2 = property(_get_leda2, _set_leda2)
     status = property(_get_status)
@@ -885,19 +876,17 @@ class Connect(Core):
     Stellt Funktionen fuer die LEDs, Watchdog und den Status zur Verfuegung.
     """
 
-    __slots__ = "__evt_wdtoggle", "__th_wdtoggle", "a3green", "a3red", "wd", \
+    __slots__ = "__evt_wdtoggle", "__th_wdtoggle", "a3green", "a3red", \
                 "x2in", "x2out"
 
     def __setattr__(self, key, value):
-        """Verhindert Ueberschreibung der LEDs."""
+        """Verhindert Ueberschreibung der speziellen IOs."""
         if hasattr(self, key) and key in (
-                "a1green", "a1red", "a2green", "a2red", "a3green", "a3red",
-                "wd", "x2in", "x2out"):
+                "a3green", "a3red", "x2in", "x2out"):
             raise AttributeError(
                 "direct assignment is not supported - use .value Attribute"
             )
-        else:
-            object.__setattr__(self, key, value)
+        super(Connect, self).__setattr__(key, value)
 
     def __wdtoggle(self) -> None:
         """WD Ausgang alle 10 Sekunden automatisch toggeln."""
@@ -941,10 +930,6 @@ class Connect(Core):
         ], OUT, "little", False)
 
         # IO Objekte für WD und X2 in/out erzeugen
-        self.wd = IOBase(self, [
-            "core.wd", 0, 1, self._slc_led.start,
-            exp_wd, None, "Connect_WatchDog", "7"
-        ], OUT, "little", False)
         self.x2in = IOBase(self, [
             "core.x2in", 0, 1, self._slc_statusbyte.start,
             exp_x2in, None, "Connect_X2_IN", "6"
@@ -960,12 +945,8 @@ class Connect(Core):
 
         :return: 0=aus, 1=gruen, 2=rot
         """
-        int_led = int.from_bytes(
-            self._ba_devdata[self._slc_led], byteorder="little"
-        ) >> 4
-        led = int_led & 1
-        led += int_led & 2
-        return led
+        # 0b00110000 = 48
+        return (self._ba_devdata[self._slc_led.start] & 48) >> 4
 
     def _get_wdtoggle(self) -> bool:
         """
@@ -982,7 +963,14 @@ class Connect(Core):
         :param: value 0=aus, 1=gruen, 2=rot
         """
         if 0 <= value <= 3:
-            self._set_calculatedled([16, 32], value << 4)
+            value <<= 4
+            proc_value = self._ba_devdata[self._slc_led.start]
+            proc_value_calc = proc_value & 48
+            if proc_value_calc == value:
+                return
+            # Set new value
+            self._ba_devdata[self._slc_led.start] = \
+                proc_value - proc_value_calc + value
         else:
             raise ValueError("led status must be between 0 and 3")
 
@@ -1023,6 +1011,155 @@ class Connect(Core):
     wdautotoggle = property(_get_wdtoggle, _set_wdtoggle)
 
 
+class Compact(Base):
+    """
+    Klasse fuer den RevPi Connect.
+
+    Stellt Funktionen fuer die LEDs zur Verfuegung. Auf IOs wird ueber das .io
+    Objekt zugegriffen.
+    """
+
+    __slots__ = "_slc_temperature", "_slc_frequency", "_slc_led", \
+                "a1green", "a1red", "a2green", "a2red", "wd"
+
+    def __setattr__(self, key, value):
+        """Verhindert Ueberschreibung der LEDs."""
+        if hasattr(self, key) and key in (
+                "a1green", "a1red", "a2green", "a2red"):
+            raise AttributeError(
+                "direct assignment is not supported - use .value Attribute"
+            )
+        else:
+            object.__setattr__(self, key, value)
+
+    def _devconfigure(self) -> None:
+        """Core-Klasse vorbereiten."""
+
+        # Statische IO Verknüpfungen des Compacts
+        self._slc_led = slice(23, 24)
+        self._slc_temperature = slice(0, 1)
+        self._slc_frequency = slice(1, 2)
+
+        # Exportflags prüfen (Byte oder Bit)
+        lst_led = self._modio.io[self._slc_devoff][self._slc_led.start]
+        if len(lst_led) == 8:
+            exp_a1green = lst_led[0].export
+            exp_a1red = lst_led[1].export
+            exp_a2green = lst_led[2].export
+            exp_a2red = lst_led[3].export
+        else:
+            exp_a1green = lst_led[0].export
+            exp_a1red = exp_a1green
+            exp_a2green = exp_a1green
+            exp_a2red = exp_a1green
+
+        # Echte IOs erzeugen
+        self.a1green = IOBase(self, [
+            "core.a1green", 0, 1, self._slc_led.start,
+            exp_a1green, None, "LED_A1_GREEN", "0"
+        ], OUT, "little", False)
+        self.a1red = IOBase(self, [
+            "core.a1red", 0, 1, self._slc_led.start,
+            exp_a1red, None, "LED_A1_RED", "1"
+        ], OUT, "little", False)
+        self.a2green = IOBase(self, [
+            "core.a2green", 0, 1, self._slc_led.start,
+            exp_a2green, None, "LED_A2_GREEN", "2"
+        ], OUT, "little", False)
+        self.a2red = IOBase(self, [
+            "core.a2red", 0, 1, self._slc_led.start,
+            exp_a2red, None, "LED_A2_RED", "3"
+        ], OUT, "little", False)
+
+        # Software watchdog einrichten
+        self.wd = IOBase(self, [
+            "core.wd", 0, 1, self._slc_led.start,
+            False, None, "WatchDog", "7"
+        ], OUT, "little", False)
+
+    def _get_leda1(self) -> int:
+        """
+        Gibt den Zustand der LED A1 vom Compact zurueck.
+
+        :return: 0=aus, 1=gruen, 2=rot
+        """
+        # 0b00000011 = 3
+        return self._ba_devdata[self._slc_led.start] & 3
+
+    def _get_leda2(self) -> int:
+        """
+        Gibt den Zustand der LED A2 vom Compact zurueck.
+
+        :return: 0=aus, 1=gruen, 2=rot
+        """
+        # 0b00001100 = 12
+        return (self._ba_devdata[self._slc_led.start] & 12) >> 2
+
+    def _set_leda1(self, value: int) -> None:
+        """
+        Setzt den Zustand der LED A1 vom Compact.
+
+        :param value: 0=aus, 1=gruen, 2=rot
+        """
+        if 0 <= value <= 3:
+            proc_value = self._ba_devdata[self._slc_led.start]
+            proc_value_calc = proc_value & 3
+            if proc_value_calc == value:
+                return
+            # Set new value
+            self._ba_devdata[self._slc_led.start] = \
+                proc_value - proc_value_calc + value
+        else:
+            raise ValueError("led status must be between 0 and 3")
+
+    def _set_leda2(self, value: int) -> None:
+        """
+        Setzt den Zustand der LED A2 vom Compact.
+
+        :param value: 0=aus, 1=gruen, 2=rot
+        """
+        if 0 <= value <= 3:
+            value <<= 2
+            proc_value = self._ba_devdata[self._slc_led.start]
+            proc_value_calc = proc_value & 12
+            if proc_value_calc == value:
+                return
+            # Set new value
+            self._ba_devdata[self._slc_led.start] = \
+                proc_value - proc_value_calc + value
+        else:
+            raise ValueError("led status must be between 0 and 3")
+
+    def wd_toggle(self):
+        """Toggle watchdog bit to prevent a timeout."""
+        self.wd.value = not self.wd.value
+
+    A1 = property(_get_leda1, _set_leda1)
+    A2 = property(_get_leda2, _set_leda2)
+
+    @property
+    def temperature(self) -> int:
+        """
+        Gibt CPU-Temperatur zurueck.
+
+        :return: CPU-Temperatur in Celsius (-273 wenn nich verfuegbar)
+        """
+        return -273 if self._slc_temperature is None else int.from_bytes(
+            self._ba_devdata[self._slc_temperature], byteorder="little"
+        )
+
+    @property
+    def frequency(self) -> int:
+        """
+        Gibt CPU Taktfrequenz zurueck.
+
+        :return: CPU Taktfrequenz in MHz (-1 wenn nicht verfuegbar)
+        """
+        return -1 if self._slc_frequency is None else int.from_bytes(
+            self._ba_devdata[self._slc_frequency], byteorder="little"
+        ) * 10
+
+
 class DioModule(Device):
     """Stellt ein DIO / DI / DO Modul dar."""
 
@@ -1117,7 +1254,7 @@ class Virtual(Gateway):
         for io in self.get_inputs():
             self._ba_devdata[io._slc_address] = io._defaultvalue
 
-        # Outputs auf Bus schreiben
+        # Inputs auf Bus schreiben
         self._modio._myfh_lck.acquire()
         try:
             self._modio._myfh.seek(self._slc_inpoff.start)
